@@ -23,7 +23,7 @@
 #include <QBitArray>
 #include <QColor>
 #include <QFont>
-#include <QVector>
+#include <QList>
 #include <QSharedDataPointer>
 #include <QMetaType>
 
@@ -48,30 +48,30 @@ class KALARMCAL_EXPORT KAAlarm
 {
 public:
     /** The basic KAAlarm action types. */
-    enum Action
+    enum class Action
     {
-        MESSAGE,   //!< KCal::Alarm::Display type: display a text message
-        FILE,      //!< KCal::Alarm::Display type: display a file (URL given by the alarm text)
-        COMMAND,   //!< KCal::Alarm::Procedure type: execute a shell command
-        EMAIL,     //!< KCal::Alarm::Email type: send an email
-        AUDIO      //!< KCal::Alarm::Audio type: play a sound file
+        Message,   //!< KCal::Alarm::Display type: display a text message
+        File,      //!< KCal::Alarm::Display type: display a file (URL given by the alarm text)
+        Command,   //!< KCal::Alarm::Procedure type: execute a shell command
+        Email,     //!< KCal::Alarm::Email type: send an email
+        Audio      //!< KCal::Alarm::Audio type: play a sound file
     };
 
     /** Alarm types.
      *  KAAlarm's of different types may be contained in a KAEvent,
      *  each KAAlarm defining a different component of the overall alarm.
      */
-    enum Type
+    enum class Type
     {
-        INVALID_ALARM       = 0,     //!< Not an alarm
-        MAIN_ALARM          = 1,     //!< THE real alarm. Must be the first in the enumeration.
-        REMINDER_ALARM      = 0x02,  //!< Reminder in advance of/after the main alarm
-        DEFERRED_ALARM      = 0x04,  //!< Deferred alarm
-        DEFERRED_REMINDER_ALARM = REMINDER_ALARM | DEFERRED_ALARM,  //!< Deferred reminder alarm
+        Invalid          = 0,     //!< Not an alarm
+        Main             = 0x01,  //!< THE real alarm. Must be the first in the enumeration.
+        Reminder         = 0x02,  //!< Reminder in advance of/after the main alarm
+        Deferred         = 0x04,  //!< Deferred alarm
+        DeferredReminder = Reminder | Deferred,  //!< Deferred reminder alarm
         // The following values must be greater than the preceding ones, to
         // ensure that in ordered processing they are processed afterwards.
-        AT_LOGIN_ALARM      = 0x10,  //!< Additional repeat-at-login trigger
-        DISPLAYING_ALARM    = 0x20   //!< Copy of the alarm currently being displayed
+        AtLogin          = 0x10,  //!< Additional repeat-at-login trigger
+        Displaying       = 0x20   //!< Copy of the alarm currently being displayed
 
                               // IMPORTANT: if any values are added to this list, ensure that the
                               //            KAEventPrivate::AlarmType enum is adjusted similarly.
@@ -156,6 +156,12 @@ private:
     friend class KAEventPrivate;
 };
 
+inline int operator&(KAAlarm::Type t1, KAAlarm::Type t2)
+{ return static_cast<int>(t1) & static_cast<int>(t2); }
+
+inline QDebug operator<<(QDebug s, KAAlarm::Type type)
+{ s << static_cast<int>(type); return s; }
+
 class KAEventPrivate;
 
 /**
@@ -182,7 +188,7 @@ class KALARMCAL_EXPORT KAEvent
 {
 public:
     /** A list of pointers to KAEvent objects. */
-    using List = QVector<KAEvent*>;
+    using List = QList<KAEvent*>;
 
     /** Email ID, equivalent to Akonadi::Item::Id. */
     using EmailId = qint64;
@@ -209,7 +215,8 @@ public:
         DISPLAY_COMMAND = 0x10000, //!< display command output in the alarm window
         REMINDER_ONCE   = 0x20000, //!< only trigger the reminder on the first recurrence
         DONT_SHOW_ERROR = 0x40000, //!< do not notify command alarm errors to user
-        NOTIFY          = 0x80000  //!< use the standard notification system instead of alarm message window
+        NOTIFY          = 0x80000, //!< use the standard notification system instead of alarm message window
+        WAKE_SUSPEND    = 0x100000 //!< use kernel timer (not RTC) to wake-from-suspend when alarm due
 
                           // IMPORTANT: if any values are added to this list, ensure that the
                           //            additional enum values in KAEventPrivate are also adjusted.
@@ -218,101 +225,115 @@ public:
 
     /** The basic action type(s) for the event's main alarm.
      *  Values may be combined by OR'ing them together. */
-    enum Actions
+    enum class Action
     {
-        ACT_NONE            = 0,      //!< invalid
-        ACT_DISPLAY         = 0x01,   //!< the alarm displays something
-        ACT_COMMAND         = 0x02,   //!< the alarm executes a command
-        ACT_EMAIL           = 0x04,   //!< the alarm sends an email
-        ACT_AUDIO           = 0x08,   //!< the alarm plays an audio file (without any display)
-        ACT_DISPLAY_COMMAND = ACT_DISPLAY | ACT_COMMAND,  //!< the alarm displays command output
-        ACT_ALL             = ACT_DISPLAY | ACT_COMMAND | ACT_EMAIL | ACT_AUDIO   //!< all types mask
+        None           = 0,      //!< invalid
+        Display        = 0x01,   //!< the alarm displays something
+        Command        = 0x02,   //!< the alarm executes a command
+        Email          = 0x04,   //!< the alarm sends an email
+        Audio          = 0x08,   //!< the alarm plays an audio file (without any display)
+        DisplayCommand = Display | Command,  //!< the alarm displays command output
+        All            = Display | Command | Email | Audio   //!< all types mask
     };
 
     /** The sub-action type for the event's main alarm. */
-    enum SubAction
+    enum class SubAction
     {
-        MESSAGE = KAAlarm::MESSAGE,    //!< display a message text
-        FILE    = KAAlarm::FILE,       //!< display the contents of a file
-        COMMAND = KAAlarm::COMMAND,    //!< execute a command
-        EMAIL   = KAAlarm::EMAIL,      //!< send an email
-        AUDIO   = KAAlarm::AUDIO       //!< play an audio file
+        Message = static_cast<int>(KAAlarm::Action::Message),  //!< display a message text
+        File    = static_cast<int>(KAAlarm::Action::File),     //!< display the contents of a file
+        Command = static_cast<int>(KAAlarm::Action::Command),  //!< execute a command
+        Email   = static_cast<int>(KAAlarm::Action::Email),    //!< send an email
+        Audio   = static_cast<int>(KAAlarm::Action::Audio)     //!< play an audio file
     };
 
     /** What type of occurrence is due. */
-    enum OccurType
+    enum class OccurType
     {
-        NO_OCCURRENCE            = 0,      //!< no occurrence is due
-        FIRST_OR_ONLY_OCCURRENCE = 0x01,   //!< the first occurrence (takes precedence over LAST_RECURRENCE)
-        RECURRENCE_DATE          = 0x02,   //!< a recurrence with only a date, not a time
-        RECURRENCE_DATE_TIME     = 0x03,   //!< a recurrence with a date and time
-        LAST_RECURRENCE          = 0x04,   //!< the last recurrence
-        OCCURRENCE_REPEAT        = 0x10,   //!< (bitmask for a sub-repetition of an occurrence)
-        FIRST_OR_ONLY_OCCURRENCE_REPEAT = OCCURRENCE_REPEAT | FIRST_OR_ONLY_OCCURRENCE, //!< a sub-repetition of the first occurrence
-        RECURRENCE_DATE_REPEAT          = OCCURRENCE_REPEAT | RECURRENCE_DATE,          //!< a sub-repetition of a date-only recurrence
-        RECURRENCE_DATE_TIME_REPEAT     = OCCURRENCE_REPEAT | RECURRENCE_DATE_TIME,     //!< a sub-repetition of a date/time recurrence
-        LAST_RECURRENCE_REPEAT          = OCCURRENCE_REPEAT | LAST_RECURRENCE           //!< a sub-repetition of the last recurrence
+        None                = 0,      //!< no occurrence is due
+        FirstOrOnly         = 0x01,   //!< the first occurrence (takes precedence over LastRecur)
+        RecurDate           = 0x02,   //!< a recurrence with only a date, not a time
+        RecurDateTime       = 0x03,   //!< a recurrence with a date and time
+        LastRecur           = 0x04,   //!< the last recurrence
+        Repeat              = 0x10,   //!< (bitmask for a sub-repetition of an occurrence)
+        FirstOrOnlyRepeat   = Repeat | FirstOrOnly,   //!< a sub-repetition of the first occurrence
+        RecurDateRepeat     = Repeat | RecurDate,     //!< a sub-repetition of a date-only recurrence
+        RecurDateTimeRepeat = Repeat | RecurDateTime, //!< a sub-repetition of a date/time recurrence
+        LastRecurRepeat     = Repeat | LastRecur      //!< a sub-repetition of the last recurrence
     };
 
     /** How to treat sub-repetitions in nextOccurrence(). */
-    enum OccurOption
+    enum class Repeats
     {
-        IGNORE_REPETITION,    //!< check for recurrences only, ignore sub-repetitions
-        RETURN_REPETITION,    //!< return a sub-repetition if it's the next occurrence
-        ALLOW_FOR_REPETITION  //!< if a sub-repetition is the next occurrence, return the previous recurrence, not the sub-repetition
+        Ignore = 0,    //!< check for recurrences only, ignore sub-repetitions
+        Return,        //!< return a sub-repetition if it's the next occurrence
+        RecurBefore    //!< if a sub-repetition is the next occurrence, return the previous recurrence, not the sub-repetition
     };
 
     /** What type of occurrence currently limits how long the alarm can be deferred. */
-    enum DeferLimitType
+    enum class DeferLimit
     {
-        LIMIT_NONE,        //!< there is no limit
-        LIMIT_MAIN,        //!< the main alarm
-        LIMIT_RECURRENCE,  //!< a recurrence
-        LIMIT_REPETITION,  //!< a sub-repetition
-        LIMIT_REMINDER     //!< a reminder
+        None,        //!< there is no limit
+        Main,        //!< the main alarm
+        Recurrence,  //!< a recurrence
+        Repetition,  //!< a sub-repetition
+        Reminder     //!< a reminder
     };
 
+    /** What to check for in nextDateTime() when evaluating the next event display or occurrence.
+     *  If the event (not a reminder) has been deferred, the deferral time is returned regardless
+     *  of NextType.
+     *  Reminders are never returned if the recurrence to which they relate is excluded by working
+     *  hours or holiday restrictions, regardless of whether or not NextWorkHoliday is specified.
+     */
+    enum NextType
+    {
+        NextRecur       = 0,      //!< (always done) check for only occurrence or next recurrence
+        NextRepeat      = 0x01,   //!< check for sub-repetitions
+        NextReminder    = 0x02,   //!< check for reminders
+        NextWorkHoliday = 0x04,   //!< take account of any working hours or holiday restrictions
+        NextDeferral    = 0x08    //!< return the event deferral time, or reminder deferral time if NextReminder set
+    };
+    Q_DECLARE_FLAGS(NextTypes, NextType)
+
     /** Next trigger type for an alarm. */
-    enum TriggerType
+    enum class Trigger
     {
 
         /** Next trigger, including reminders. No account is taken of any
          *  working hours or holiday restrictions when evaluating this. */
-        ALL_TRIGGER,
+        All,
 
         /** Next trigger of the main alarm, i.e. excluding reminders. No
          *  account is taken of any working hours or holiday restrictions when
          *  evaluating this. */
-        MAIN_TRIGGER,
+        Main,
 
         /** Next trigger of the main alarm, i.e. excluding reminders, taking
          *  account of any working hours or holiday restrictions. If the event
          *  has no working hours or holiday restrictions, this is equivalent to
-         *  MAIN_TRIGGER. */
-        WORK_TRIGGER,
+         *  Main. */
+        Work,
 
         /** Next trigger, including reminders, taking account of any working
          *  hours or holiday restrictions. If the event has no working hours or
-         *  holiday restrictions, this is equivalent to ALL_TRIGGER. */
-        ALL_WORK_TRIGGER,
+         *  holiday restrictions, this is equivalent to All. */
+        AllWork,
 
         /** Next trigger time for display purposes (i.e. excluding reminders). */
-        DISPLAY_TRIGGER
+        Display
     };
 
     /** Command execution error type for last time the alarm was triggered. */
-    enum CmdErrType
+    enum class CmdErr
     {
-        CMD_NO_ERROR   = 0,      //!< no error
-        CMD_ERROR      = 0x01,   //!< command alarm execution failed
-        CMD_ERROR_PRE  = 0x02,   //!< pre-alarm command execution failed
-        CMD_ERROR_POST = 0x04,   //!< post-alarm command execution failed
-        CMD_ERROR_PRE_POST = CMD_ERROR_PRE | CMD_ERROR_POST
+        None    = 0,      //!< no error
+        Fail    = 0x01,   //!< command alarm execution failed
+        Pre     = 0x02,   //!< pre-alarm command execution failed
+        Post    = 0x04,   //!< post-alarm command execution failed
+        PrePost = Pre | Post
     };
 
-    /** Options for pre- or post-alarm actions. These may be OR'ed together.
-     *  @since 4.9
-     */
+    /** Options for pre- or post-alarm actions. These may be OR'ed together. */
     enum ExtraActionOption
     {
         CancelOnPreActError  = 0x01,   //!< cancel alarm on pre-alarm action error
@@ -322,11 +343,11 @@ public:
     Q_DECLARE_FLAGS(ExtraActionOptions, ExtraActionOption)
 
     /** How to deal with the event UID in updateKCalEvent(). */
-    enum UidAction
+    enum class UidAction
     {
-        UID_IGNORE,        //!< leave KCal::Event UID unchanged
-        UID_CHECK,         //!< verify that the KCal::Event UID is already the same as the KAEvent ID, if the latter is non-empty
-        UID_SET            //!< set the KCal::Event UID to the KAEvent ID
+        Ignore,        //!< leave KCal::Event UID unchanged
+        Check,         //!< verify that the KCal::Event UID is already the same as the KAEvent ID, if the latter is non-empty
+        Set            //!< set the KCal::Event UID to the KAEvent ID
     };
 
     /** Default constructor which creates an invalid event. */
@@ -336,11 +357,11 @@ public:
      *  @param dt    start date/time. If @p dt is date-only, or if #ANY_TIME flag
      *               is specified, the event will be date-only.
      *  @param name  name of the alarm.
-     *  @param text  alarm message (@p action = #MESSAGE);
-     *               file to display (@p action = #FILE);
-     *               command to execute (@p action = #COMMAND);
-     *               email body (@p action = #EMAIL);
-     *               audio file (@p action = #AUDIO).
+     *  @param text  alarm message (@p action = #Message);
+     *               file to display (@p action = #File);
+     *               command to execute (@p action = #Command);
+     *               email body (@p action = #Email);
+     *               audio file (@p action = #Audio).
      *  @param bg    background color (for display alarms, ignored otherwise).
      *  @param fg    foreground color (for display alarms, ignored otherwise).
      *  @param font  font (for display alarms, ignored otherwise). Ignored if
@@ -452,19 +473,19 @@ public:
     QMap<QByteArray, QString> customProperties() const;
 
     /** Return the action sub-type of the event's main alarm. For display alarms,
-     *  this is MESSAGE or FILE, while other types of alarm simply return the
-     *  basic action type (COMMAND, EMAIL, AUDIO).
+     *  this is Message or File, while other types of alarm simply return the
+     *  basic action type (Command, Email, Audio).
      *  Note that for a display alarm whose text is generated by a command, the
-     *  returned type is COMMAND.
+     *  returned type is Command.
      */
     SubAction actionSubType() const;
 
     /** Return the OR of the basic action types of the event's main alarm (display,
      *  command, email, audio).
      *  Note that for a display alarm whose text is generated by a command, the
-     *  returned type is @c ACT_DISPLAY|ACT_COMMAND.
+     *  returned type is @c Action::Display|Action::Command.
      */
-    Actions actionTypes() const;
+    Action actionTypes() const;
 
     /** Set or clear the late-cancel option. This determines whether the alarm
      *  will be cancelled if it is late in triggering.
@@ -574,14 +595,12 @@ public:
     bool commandDisplay() const;
 
     /** Set or clear the command execution error for the last time the alarm triggered. */
-    void setCommandError(CmdErrType error) const;
+    void setCommandError(CmdErr error) const;
 
     /** Return the command execution error for the last time the alarm triggered. */
-    CmdErrType commandError() const;
+    CmdErr commandError() const;
 
-    /** Return whether execution errors for the command should not to be shown to the user.
-     *  @since 20.08
-     */
+    /** Return whether execution errors for the command should not to be shown to the user. */
     bool commandHideError() const;
 
     /** Set the log file to write command alarm output to.
@@ -731,7 +750,6 @@ public:
      *  @param post shell command to execute after the alarm is acknowledged
      *  @param preOptions options for pre-alarm actions
      *  @see preAction(), postAction(), extraActionOptions()
-     *  @since 4.9
      */
     void setActions(const QString& pre, const QString& post, ExtraActionOptions preOptions);
 
@@ -745,7 +763,6 @@ public:
 
     /** Return the pre-alarm action options.
      *  @see preAction(), setActions()
-     *  @since 4.9
      */
     ExtraActionOptions extraActionOptions() const;
 
@@ -826,7 +843,7 @@ public:
      *                    the type of occurrence which currently limits the deferral.
      *  @return deferral limit, or invalid if no limit
      */
-    DateTime deferralLimit(DeferLimitType* limitType = nullptr) const;
+    DateTime deferralLimit(DeferLimit* limitType = nullptr) const;
 
     /** Return the default deferral interval used in the deferral dialog.
      *  @see setDeferDefaultMinutes()
@@ -852,6 +869,27 @@ public:
      */
     void setTime(const KADateTime& dt);
 
+    /** Return the next time the event will trigger or be displayed. The evaluation
+     *  depends on @p type:
+     * - @p type == NextRecur:             returns the next recurrence or only occurrence.
+     * - @p type contains NextRepeat:      returns the only occurrence or next
+     *                                     recurrence/sub-repetition.
+     * - @p type contains NextReminder:    as above but if a reminder occurs first, it will
+     *                                     be returned. N.B. Reminders are not displayed for
+     *                                     sub-repetitions.
+     * - @p type contains NextWorkHoliday: as above but the search continues until a
+     *                                     recurrence is found which occurs during working
+     *                                     hours and not on a holiday.
+     * - @p type contains NextDeferral:    if the event (not a reminder) has been deferred,
+     *                                     returns the deferral time.
+     *                                     If a reminder has been deferred AND @p type
+     *                                     contains NextReminder, returns the deferral time.
+     *
+     *  @param type  what to check for when evaluating the next occurrence or display.
+     *  @see startDateTime(), setTime()
+     */
+    DateTime nextDateTime(NextTypes type) const;
+
     /** Return the next time the main alarm will trigger.
      *  @note No account is taken of any working hours or holiday restrictions.
      *        when determining the next trigger date/time.
@@ -895,7 +933,7 @@ public:
      *  @param type specifies whether to ignore reminders, working time
      *              restrictions, etc.
      */
-    DateTime nextTrigger(TriggerType type) const;
+    DateTime nextTrigger(Trigger type) const;
 
     /** Set the date/time the event was created, or saved in the archive calendar.
      *  @see createdDateTime()
@@ -921,6 +959,20 @@ public:
      */
     bool repeatAtLogin(bool includeArchived = false) const;
 
+    /** Enable or disable wake-from-suspend when the alarm is due.
+     *  (Note that this option is used for kernel timer wake-from-suspend, not
+     *   for RTC wake-from-suspend, since the latter can only be set for one
+     *   alarm at any one time.)
+     *  @param wake  true to wake-from-suspend, false to not wake-from-suspend.
+     *  @see wakeFromSuspend()
+     */
+    void setWakeFromSuspend(bool wake);
+
+    /** Return whether wake-from-suspend is enabled for the alarm.
+     *  @see setWakeFromSuspend()
+     */
+    bool wakeFromSuspend() const;
+
     /** Enable or disable the alarm on holiday dates. The currently selected
      *  holiday region determines which dates are holidays.
      *  Note that this option only has any effect for recurring alarms.
@@ -961,6 +1013,8 @@ public:
 
     /** Check whether a date/time conflicts with working hours and/or holiday
      *  restrictions for the alarm.
+     *  @note If @p dt is date-only, only holidays and/or working days are
+     *        taken account of; working hours are ignored.
      *  @param dt  the date/time to check.
      *  @return true if the alarm is disabled from occurring at time @p dt
      *               because @p dt is outside working hours (if the alarm is
@@ -1033,7 +1087,7 @@ public:
      *  @param end   = end date (set invalid to use @p count instead).
      *  @return @c false if no recurrence was set up.
      */
-    bool setRecurMonthlyByDate(int freq, const QVector<int>& days, int count, QDate end);
+    bool setRecurMonthlyByDate(int freq, const QList<int>& days, int count, QDate end);
 
     /** Holds days of the week combined with a week number in the month,
      *  used to specify some monthly or annual recurrences. */
@@ -1054,7 +1108,7 @@ public:
      *  @param end   = end date (set invalid to use @p count instead).
      *  @return @c false if no recurrence was set up.
      */
-    bool setRecurMonthlyByPos(int freq, const QVector<MonthPos>& pos, int count, QDate end);
+    bool setRecurMonthlyByPos(int freq, const QList<MonthPos>& pos, int count, QDate end);
 
     /** Set the recurrence to recur annually, on the specified day in each
      *  of the specified months.
@@ -1069,7 +1123,7 @@ public:
      *  @param end   = end date (set invalid to use @p count instead).
      *  @return @c false if no recurrence was set up.
      */
-    bool setRecurAnnualByDate(int freq, const QVector<int>& months, int day, KARecurrence::Feb29Type, int count, QDate end);
+    bool setRecurAnnualByDate(int freq, const QList<int>& months, int day, KARecurrence::Feb29Type, int count, QDate end);
 
     /** Set the recurrence to recur annually, on the specified weekdays in the
      *  specified weeks of the specified months.
@@ -1082,7 +1136,7 @@ public:
      *  @param end   = end date (set invalid to use @p count instead).
      *  @return @c false if no recurrence was set up.
      */
-    bool setRecurAnnualByPos(int freq, const QVector<MonthPos>& pos, const QVector<int>& months, int count, QDate end);
+    bool setRecurAnnualByPos(int freq, const QList<MonthPos>& pos, const QList<int>& months, int count, QDate end);
 
     /** Return whether the event recurs.
      *  @see recurType()
@@ -1154,6 +1208,8 @@ public:
      *  date/time. Reminders are ignored.
      *  @note No account is taken of any working hours or holiday restrictions
      *        when determining event occurrences.
+     *  @note If the event is date-only, its occurrences are considered to occur
+     *        at the start-of-day time when comparing with @p preDateTime.
      *
      *  @param preDateTime        the specified date/time.
      *  @param includeRepetitions if true and the alarm has a sub-repetition, the
@@ -1171,6 +1227,8 @@ public:
      *  set as the next occurrence.
      *  @note No account is taken of any working hours or holiday restrictions
      *        when determining and setting the next occurrence date/time.
+     *  @note If the event is date-only, its occurrences are considered to occur
+     *        at the start-of-day time when comparing with @p preDateTime.
      *
      *  @see nextOccurrence()
      */
@@ -1180,18 +1238,22 @@ public:
      *  the specified date/time. Reminders are ignored.
      *  @note No account is taken of any working hours or holiday restrictions
      *        when determining the next event occurrence.
+     *  @note If the event is date-only, its occurrences are considered to occur
+     *        at the start-of-day time when comparing with @p preDateTime.
      *
      *  @param preDateTime the specified date/time.
      *  @param result      date/time of next occurrence, or invalid date/time if none.
      *  @param option      how/whether to make allowance for sub-repetitions.
      *  @see nextRepetition(), setNextOccurrence(), previousOccurrence(), occursAfter()
      */
-    OccurType nextOccurrence(const KADateTime& preDateTime, DateTime& result, OccurOption option = IGNORE_REPETITION) const;
+    OccurType nextOccurrence(const KADateTime& preDateTime, DateTime& result, Repeats option = Repeats::Ignore) const;
 
     /** Get the date/time of the last previous occurrence of the event,
      *  strictly before the specified date/time. Reminders are ignored.
      *  @note No account is taken of any working hours or holiday restrictions
      *        when determining the previous event occurrence.
+     *  @note If the event is date-only, its occurrences are considered to occur
+     *        at the start-of-day time when comparing with @p preDateTime.
      *
      *  @param afterDateTime       the specified date/time.
      *  @param result              date/time of previous occurrence, or invalid
@@ -1212,7 +1274,7 @@ public:
      *  @param event      the event to copy
      *  @param type       the alarm type (main, reminder, deferred etc.)
      *  @param colId      the ID of the calendar resource which originally contained the event
-     *  @param repeatAtLoginTime repeat-at-login time if @p type == AT_LOGIN_ALARM, else ignored
+     *  @param repeatAtLoginTime repeat-at-login time if @p type == AtLogin, else ignored
      *  @param showEdit   whether the Edit button was displayed
      *  @param showDefer  whether the Defer button was displayed
      *  @return @c true if successful, @c false if alarm was not copied.
@@ -1347,7 +1409,7 @@ public:
     static bool convertKCalEvents(const KCalendarCore::Calendar::Ptr&, int calendarVersion);
 
     /** Return a list of pointers to a list of KAEvent objects. */
-    static List ptrList(QVector<KAEvent>& events);
+    static List ptrList(QList<KAEvent>& events);
 
     /** Output the event's data as debug output. */
     void dumpDebug() const;
@@ -1356,10 +1418,38 @@ private:
     QSharedDataPointer<KAEventPrivate> d;
 };
 
+inline int operator&(KAEvent::Action a1, KAEvent::Action a2)
+{ return static_cast<int>(a1) & static_cast<int>(a2); }
+
+inline KAEvent::Action operator~(KAEvent::Action act)
+{ return static_cast<KAEvent::Action>(~static_cast<int>(act)); }
+
+inline QDebug operator<<(QDebug s, KAEvent::Action act)
+{ s << static_cast<int>(act); return s; }
+
+inline int operator&(KAEvent::OccurType t1, KAEvent::OccurType t2)
+{ return static_cast<int>(t1) & static_cast<int>(t2); }
+
+inline KAEvent::OccurType operator|(KAEvent::OccurType t1, KAEvent::OccurType t2)
+{ return static_cast<KAEvent::OccurType>(static_cast<int>(t1) | static_cast<int>(t2)); }
+
+inline KAEvent::OccurType operator~(KAEvent::OccurType type)
+{ return static_cast<KAEvent::OccurType>(~static_cast<int>(type)); }
+
+inline int operator&(KAEvent::CmdErr e1, KAEvent::CmdErr e2)
+{ return static_cast<int>(e1) & static_cast<int>(e2); }
+
+inline KAEvent::CmdErr operator~(KAEvent::CmdErr err)
+{ return static_cast<KAEvent::CmdErr>(~static_cast<int>(err)); }
+
+inline QDebug operator<<(QDebug s, KAEvent::CmdErr err)
+{ s << static_cast<int>(err); return s; }
+
 } // namespace KAlarmCal
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KAlarmCal::KAEvent::Flags)
 Q_DECLARE_OPERATORS_FOR_FLAGS(KAlarmCal::KAEvent::Comparison)
+Q_DECLARE_OPERATORS_FOR_FLAGS(KAlarmCal::KAEvent::NextTypes)
 Q_DECLARE_METATYPE(KAlarmCal::KAEvent)
 
 // vim: et sw=4:
