@@ -19,8 +19,8 @@
 
 #include "kmailinterface.h"
 
-#include <KIdentityManagement/IdentityManager>
-#include <KIdentityManagement/Identity>
+#include <KIdentityManagementCore/IdentityManager>
+#include <KIdentityManagementCore/Identity>
 #include <KMime/HeaderParsing>
 #include <KMime/Headers>
 #include <KMime/Message>
@@ -91,7 +91,7 @@ KAMail* KAMail::instance()
 int KAMail::send(JobData& jobdata, QStringList& errmsgs)
 {
     QString err;
-    KIdentityManagement::Identity identity;
+    KIdentityManagementCore::Identity identity;
     jobdata.from = Preferences::emailAddress();
     if (jobdata.event.emailFromId()
     &&  Preferences::emailFrom() == Preferences::MAIL_FROM_KMAIL)
@@ -287,7 +287,7 @@ QString KAMail::appendBodyAttachments(KMime::Message& message, JobData& data)
             bool atterror = false;
             if (!url.isLocalFile())
             {
-                auto statJob = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatDetail::StatDefaultDetails);
+                auto statJob = KIO::stat(url, KIO::StatJob::SourceSide, KIO::StatDetail::StatDefaultDetails);
                 KJobWidgets::setWindow(statJob, MainWindow::mainMainWindow());
                 if (!statJob->exec())
                 {
@@ -860,4 +860,6 @@ bool parseAddress(const char* & scursor, const char* const send, Address& result
 
 } // namespace HeaderParsing
 
+#include "moc_kamail.cpp"
+
 // vim: et sw=4:
